@@ -18,17 +18,21 @@
 """Thoth components classes to process outputs."""
 
 from .adviser import Adviser
-from .inspection import AmunInspection
+from .inspection import AmunInspections
 from .inspection import AmunInspectionsSummary
+from .inspection import AmunInspectionsStatistics
 from .security import SecurityIndicatorsBandit
 from .security import SecurityIndicatorsCloc
 from .security import SecurityIndicatorsAggregator
+from .solver import Solver
 
 __all__ = [
     "Adviser",
-    "AmunInspection",
+    "AmunInspections",
+    "AmunInspectionsStatistics",
     "AmunInspectionsSummary",
     "SecurityIndicatorsBandit",
     "SecurityIndicatorsCloc",
     "SecurityIndicatorsAggregator",
+    "Solver",
 ]
