@@ -338,11 +338,11 @@ class AmunInspections:
                         if not os.path.exists(result_path):
                             os.makedirs(result_path)
 
-                    with open(
-                        f"{store_locally_repo_name}/{inspection_document_id}/results/{inspection_result_number}/result",
-                        "w",
-                    ) as result_file:
-                        result_file.write(json.dumps(inspection_result_document))
+                        with open(
+                            f"{store_locally_repo_name}/{inspection_document_id}/results/{inspection_result_number}/result",
+                            "w",
+                        ) as result_file:
+                            result_file.write(json.dumps(inspection_result_document))
 
                 if store_files and ThothAmunInspectionFileStoreEnum.hardware_info.name in store_files:
                     inspection_hw_info = inspection_store.results.retrieve_hwinfo(
@@ -680,7 +680,7 @@ class AmunInspections:
                     inspection_duration = inspection_end - inspection_start
 
             elif c_name in unashable_columns.index.values:
-                if c_name == "hwinfo__cpu_features__flags":
+                if c_name == "__hwinfo__cpu_features__flags":
                     initial_set = set(inspection_df[c_name][0])
                     difference = False
                     for flags_counter in range(1, len(inspection_df[c_name])):
@@ -743,18 +743,29 @@ class AmunInspections:
         row_number = 0
         extracted_columns = []
         flags_columns = []
+        flags_dfs = {}
 
+        # Identify subset of columns to be considered for final results
         for dataframe in processed_inspection_runs.values():
 
             for column in dataframe.columns.values:
                 if column not in extracted_columns:
                     extracted_columns.append(column)
 
-            for flags in dataframe["hwinfo__cpu_features__flags"].values:
+            flags_dict = {}
+            for flags in dataframe["__hwinfo__cpu_features__flags"].values:
                 for flag in flags:
                     if f"flag__{flag}" not in flags_columns:
                         flags_columns.append(f"flag__{flag}")
 
+                    if f"flag__{flag}" not in flags_dict:
+                        flags_dict[f"flag__{flag}"] = True
+
+            flags_df = pd.DataFrame.from_dict(flags_dict, orient="index")
+            flags_dfs[str(row_number)] = flags_df
+
+            row_number += 1
+
         for flag_column in flags_columns:
             extracted_columns.append(flag_column)
 
@@ -762,27 +773,32 @@ class AmunInspections:
         for extra_column in extra_columns:
             extracted_columns.append(extra_column)
 
-        main_inspection_df = pd.DataFrame(columns=extracted_columns)
-
+        # Select columns where statistics can be performed
         column_names = [
             cls._INSPECTION_PERFORMANCE_VALUES[p_value] for p_value in performance_values
         ] + cls._INSPECTION_USAGE_VALUES
 
+        # Create final dataframe with all inspection results
+        row_number = 0
+        data = []
+
         for dataframe in processed_inspection_runs.values():
 
+            # Create dataframe with statistics
             new_df = cls.evaluate_statistics_on_inspection_df(
                 inspection_df=dataframe,
                 column_names=column_names,
                 extra_columns=extra_columns,
             )
 
-            for flags_ in dataframe["hwinfo__cpu_features__flags"].values:
-                for flag_ in flags_:
-                    new_df[f"flag__{flag_}"] = True
+            # concatenate with dataframe with flagsz
+            new_df = pd.concat([new_df, flags_dfs[str(row_number)].T], axis=1)
 
-            main_inspection_df.loc[row_number] = new_df.iloc[0]
+            data.append(new_df)
             row_number += 1
 
+            main_inspection_df = pd.concat(data, axis=0)
+
         if include_statistics:
             inspections_statistics_dataframe = AmunInspectionsStatistics.create_inspections_statistics_dataframe(
                 processed_inspection_runs=processed_inspection_runs,
@@ -808,18 +824,18 @@ class AmunInspections:
 
         for c_name in sws_df.columns.values:
             if "__index" in c_name:
-                python_packages_names.append(c_name.split("__")[2])
+                python_packages_names.append(c_name.split("__")[3])
 
         columns_packages = []
         for package in python_packages_names:
-            columns_packages.append("".join(["requirements_locked__default__", package, "__index"]))
-            columns_packages.append("".join(["requirements_locked__default__", package, "__version"]))
+            columns_packages.append("".join(["__requirements_locked__default__", package, "__index"]))
+            columns_packages.append("".join(["__requirements_locked__default__", package, "__version"]))
 
         for index, row in inspections_df[columns_packages].iterrows():
 
             for package in python_packages_names:
-                version = row["".join(["requirements_locked__default__", package, "__version"])]
-                index = row["".join(["requirements_locked__default__", package, "__index"])]
+                version = row["".join(["__requirements_locked__default__", package, "__version"])]
+                index = row["".join(["__requirements_locked__default__", package, "__index"])]
 
                 if pd.isnull(version):
                     if package not in python_packages_versions.keys():
@@ -881,7 +897,7 @@ class AmunInspections:
         re_encoded = []
 
         for index, row in inspections_df[
-            ["os_release__id", "os_release__version_id", "requirements_locked___meta__requires__python_version"]
+            ["__os_release__id", "__os_release__version_id", "__requirements_locked___meta__requires__python_version"]
         ].iterrows():
             re_values = [re for re in row.values]
             re_values[2] = "".join(["py", "".join(re_values[2].split("."))])
@@ -917,32 +933,32 @@ class AmunInspections:
         # Hardware:
         # CPU
         processed_string_result["cpu_brand"] = [
-            cpu_brand[0] for cpu_brand in inspections_df[["hwinfo__cpu_info__brand_raw"]].values
+            cpu_brand[0] for cpu_brand in inspections_df[["__hwinfo__cpu_info__brand_raw"]].values
         ]
         processed_string_result["cpu_family"] = [
-            cpu_family[0] for cpu_family in inspections_df[["runtime_environment__hardware__cpu_family"]].values
+            cpu_family[0] for cpu_family in inspections_df[["__runtime_environment__hardware__cpu_family"]].values
         ]
         processed_string_result["cpu_model"] = [
-            cpu_model[0] for cpu_model in inspections_df[["runtime_environment__hardware__cpu_model"]].values
+            cpu_model[0] for cpu_model in inspections_df[["__runtime_environment__hardware__cpu_model"]].values
         ]
         processed_string_result["number_cpus"] = [
-            number_cpus[0] for number_cpus in inspections_df[["run__requests__cpu"]].values
+            number_cpus[0] for number_cpus in inspections_df[["__run__requests__cpu"]].values
         ]
         # GPU
         processed_string_result["cuda_version"] = [
-            cuda_version[0] for cuda_version in inspections_df[["runtime_environment__cuda_version"]].values
+            cuda_version[0] for cuda_version in inspections_df[["__runtime_environment__cuda_version"]].values
         ]
 
         # PI
-        processed_string_result["pi_name"] = [pi_n[0] for pi_n in inspections_df[["stdout__name"]].values]
-        processed_string_result["pi_component"] = [pi_c[0] for pi_c in inspections_df[["stdout__component"]].values]
+        processed_string_result["pi_name"] = [pi_n[0] for pi_n in inspections_df[["__stdout__name"]].values]
+        processed_string_result["pi_component"] = [pi_c[0] for pi_c in inspections_df[["__stdout__component"]].values]
         processed_string_result["pi_sha256"] = [pi_c[0] for pi_c in inspections_df[["script_sha256"]].values]
 
         # PI performance results
         processed_string_result["elapsed_time"] = [
-            r_e[0] for r_e in inspections_df[["stdout__@result__elapsed"]].values
+            r_e[0] for r_e in inspections_df[["__stdout__@result__elapsed"]].values
         ]
-        processed_string_result["rate"] = [r_r[0] for r_r in inspections_df[["stdout__@result__rate"]].values]
+        processed_string_result["rate"] = [r_r[0] for r_r in inspections_df[["__stdout__@result__rate"]].values]
 
         processed_string_result["inspection_document_id"] = [
             i[0] for i in inspections_df[["inspection_document_id"]].values
@@ -970,14 +986,14 @@ class AmunInspections:
 
             standardized_identifiers.append(identifier_filter)
 
-        final_df["identifier"] = inspections_df["identifier"]
+        final_df["identifier"] = inspections_df["identifier"].values
         final_df["standardized_identifier"] = standardized_identifiers
 
-        final_df["start_datetime"] = inspections_df["inspection_start"]
-        final_df["end_datetime"] = inspections_df["inspection_end"]
+        final_df["start_datetime"] = inspections_df["inspection_start"].values
+        final_df["end_datetime"] = inspections_df["inspection_end"].values
 
-        final_df["total_duration"] = inspections_df["inspection_duration"]
-        final_df["inspection_batch"] = inspections_df["inspection_batch"]
+        final_df["total_duration"] = inspections_df["inspection_duration"].values
+        final_df["inspection_batch"] = inspections_df["inspection_batch"].values
 
         if include_statistics:
             final_df["statistical_parameter"] = inspections_df["statistical_parameter"]
